==> maven-plugin-1.395-sources.jar: hudson/maven/Messages.java <==
// CHECKSTYLE:OFF

package hudson.maven;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Kept because {0} is kept
     * 
     */
    public static String MavenBuild_KeptBecauseOfParent(Object arg1) {
        return holder.format("MavenBuild.KeptBecauseOfParent", arg1);
    }

    /**
     * Kept because {0} is kept
     * 
     */
    public static Localizable _MavenBuild_KeptBecauseOfParent(Object arg1) {
        return new Localizable(holder, "MavenBuild.KeptBecauseOfParent", arg1);
    }

    /**
     * Release New Version
     * 
     */
    public static String ReleaseAction_DisplayName() {
        return holder.format("ReleaseAction.DisplayName");
    }

    /**
     * Release New Version
     * 
     */
    public static Localizable _ReleaseAction_DisplayName() {
        return new Localizable(holder, "ReleaseAction.DisplayName");
    }

    /**
     * Monitor Maven Process
     * 
     */
    public static String MavenProbeAction_DisplayName() {
        return holder.format("MavenProbeAction.DisplayName");
    }

    /**
     * Monitor Maven Process
     * 
     */
    public static Localizable _MavenProbeAction_DisplayName() {
        return new Localizable(holder, "MavenProbeAction.DisplayName");
    }

    /**
     * Discovered a new module {0} {1}
     * 
     */
    public static String MavenModuleSetBuild_DiscoveredModule(Object arg1, Object arg2) {
        return holder.format("MavenModuleSetBuild.DiscoveredModule", arg1, arg2);
    }

    /**
     * Discovered a new module {0} {1}
     * 
     */
    public static Localizable _MavenModuleSetBuild_DiscoveredModule(Object arg1, Object arg2) {
        return new Localizable(holder, "MavenModuleSetBuild.DiscoveredModule", arg1, arg2);
    }

    /**
     * No such file {0}
     * Perhaps you need to specify the correct POM file path in the project configuration?
     * 
     */
    public static String MavenModuleSetBuild_NoSuchPOMFile(Object arg1) {
        return holder.format("MavenModuleSetBuild.NoSuchPOMFile", arg1);
    }

    /**
     * No such file {0}
     * Perhaps you need to specify the correct POM file path in the project configuration?
     * 
     */
    public static Localizable _MavenModuleSetBuild_NoSuchPOMFile(Object arg1) {
        return new Localizable(holder, "MavenModuleSetBuild.NoSuchPOMFile", arg1);
    }

    /**
     * No classworlds*.jar found in {0} -- Is this a valid maven2/3 directory?
     * 
     */
    public static String MavenProcessFactory_ClassWorldsNotFound(Object arg1) {
        return holder.format("MavenProcessFactory.ClassWorldsNotFound", arg1);
    }

    /**
     * No classworlds*.jar found in {0} -- Is this a valid maven2/3 directory?
     * 
     */
    public static Localizable _MavenProcessFactory_ClassWorldsNotFound(Object arg1) {
        return new Localizable(holder, "MavenProcessFactory.ClassWorldsNotFound", arg1);
    }

    /**
     * No such settings file {0} exists
     * Please verify that your alternate settings file is specified properly and exists in the workspace.
     * 
     */
    public static String MavenModuleSetBuild_NoSuchAlternateSettings(Object arg1) {
        return holder.format("MavenModuleSetBuild.NoSuchAlternateSettings", arg1);
    }

    /**
     * No such settings file {0} exists
     * Please verify that your alternate settings file is specified properly and exists in the workspace.
     * 
     */
    public static Localizable _MavenModuleSetBuild_NoSuchAlternateSettings(Object arg1) {
        return new Localizable(holder, "MavenModuleSetBuild.NoSuchAlternateSettings", arg1);
    }

    /**
     * Maven failed with error.
     * 
     */
    public static String MavenBuilder_Failed() {
        return holder.format("MavenBuilder.Failed");
    }

    /**
     * Maven failed with error.
     * 
     */
    public static Localizable _MavenBuilder_Failed() {
        return new Localizable(holder, "MavenBuilder.Failed");
    }

    /**
     * Aborted
     * 
     */
    public static String MavenBuilder_Aborted() {
        return holder.format("MavenBuilder.Aborted");
    }

    /**
     * Aborted
     * 
     */
    public static Localizable _MavenBuilder_Aborted() {
        return new Localizable(holder, "MavenBuilder.Aborted");
    }

    /**
     * Repository URL is mandatory
     * 
     */
    public static String RedeployPublisher_RepositoryURL_Mandatory() {
        return holder.format("RedeployPublisher.RepositoryURL.Mandatory");
    }

    /**
     * Repository URL is mandatory
     * 
     */
    public static Localizable _RedeployPublisher_RepositoryURL_Mandatory() {
        return new Localizable(holder, "RedeployPublisher.RepositoryURL.Mandatory");
    }

    /**
     * Build failed before it gets to this module
     * 
     */
    public static String MavenBuild_FailedEarlier() {
        return holder.format("MavenBuild.FailedEarlier");
    }

    /**
     * Build failed before it gets to this module
     * 
     */
    public static Localizable _MavenBuild_FailedEarlier() {
        return new Localizable(holder, "MavenBuild.FailedEarlier");
    }

    /**
     * Deploy artifacts to Maven repository
     * 
     */
    public static String RedeployPublisher_getDisplayName() {
        return holder.format("RedeployPublisher.getDisplayName");
    }

    /**
     * Deploy artifacts to Maven repository
     * 
     */
    public static Localizable _RedeployPublisher_getDisplayName() {
        return new Localizable(holder, "RedeployPublisher.getDisplayName");
    }

    /**
     * Module
     * 
     */
    public static String MavenModule_Pronoun() {
        return holder.format("MavenModule.Pronoun");
    }

    /**
     * Module
     * 
     */
    public static Localizable _MavenModule_Pronoun() {
        return new Localizable(holder, "MavenModule.Pronoun");
    }

    /**
     * Triggering a new build of {0}
     * 
     */
    public static String MavenBuild_Triggering(Object arg1) {
        return holder.format("MavenBuild.Triggering", arg1);
    }

    /**
     * Triggering a new build of {0}
     * 
     */
    public static Localizable _MavenBuild_Triggering(Object arg1) {
        return new Localizable(holder, "MavenBuild.Triggering", arg1);
    }

    /**
     * Asynchronous execution failure
     * 
     */
    public static String MavenBuilder_AsyncFailed() {
        return holder.format("MavenBuilder.AsyncFailed");
    }

    /**
     * Asynchronous execution failure
     * 
     */
    public static Localizable _MavenBuilder_AsyncFailed() {
        return new Localizable(holder, "MavenBuilder.AsyncFailed");
    }

    /**
     * Deploy to Maven repository
     * 
     */
    public static String MavenRedeployer_DisplayName() {
        return holder.format("MavenRedeployer.DisplayName");
    }

    /**
     * Deploy to Maven repository
     * 
     */
    public static Localizable _MavenRedeployer_DisplayName() {
        return new Localizable(holder, "MavenRedeployer.DisplayName");
    }

    /**
     * A Maven installation needs to be available for this project to be built.
     * Either your server has no Maven installations defined, or the requested Maven version does not exist.
     * 
     */
    public static String MavenModuleSetBuild_NoMavenInstall() {
        return holder.format("MavenModuleSetBuild.NoMavenInstall");
    }

    /**
     * A Maven installation needs to be available for this project to be built.
     * Either your server has no Maven installations defined, or the requested Maven version does not exist.
     * 
     */
    public static Localizable _MavenModuleSetBuild_NoMavenInstall() {
        return new Localizable(holder, "MavenModuleSetBuild.NoMavenInstall");
    }

    /**
     * Build a maven2/3 project
     * 
     */
    public static String MavenModuleSet_DiplayName() {
        return holder.format("MavenModuleSet.DiplayName");
    }

    /**
     * Build a maven2/3 project
     * 
     */
    public static Localizable _MavenModuleSet_DiplayName() {
        return new Localizable(holder, "MavenModuleSet.DiplayName");
    }

    /**
     * Reusing existing maven process
     * 
     */
    public static String ProcessCache_Reusing() {
        return holder.format("ProcessCache.Reusing");
    }

    /**
     * Reusing existing maven process
     * 
     */
    public static Localizable _ProcessCache_Reusing() {
        return new Localizable(holder, "ProcessCache.Reusing");
    }

    /**
     * Waiting for Hudson to finish collecting data
     * 
     */
    public static String MavenBuilder_Waiting() {
        return holder.format("MavenBuilder.Waiting");
    }

    /**
     * Waiting for Hudson to finish collecting data
     * 
     */
    public static Localizable _MavenBuilder_Waiting() {
        return new Localizable(holder, "MavenBuilder.Waiting");
    }

    /**
     * Failed to parse POMs
     * 
     */
    public static String MavenModuleSetBuild_FailedToParsePom() {
        return holder.format("MavenModuleSetBuild.FailedToParsePom");
    }

    /**
     * Failed to parse POMs
     * 
     */
    public static Localizable _MavenModuleSetBuild_FailedToParsePom() {
        return new Localizable(holder, "MavenModuleSetBuild.FailedToParsePom");
    }

}

==> maven-plugin-1.410-sources.jar: hudson/maven/Messages.java <==
// CHECKSTYLE:OFF

package hudson.maven;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Kept because {0} is kept
     * 
     */
    public static String MavenBuild_KeptBecauseOfParent(Object arg1) {
        return holder.format("MavenBuild.KeptBecauseOfParent", arg1);
    }

    /**
     * Kept because {0} is kept
     * 
     */
    public static Localizable _MavenBuild_KeptBecauseOfParent(Object arg1) {
        return new Localizable(holder, "MavenBuild.KeptBecauseOfParent", arg1);
    }

    /**
     * Release New Version
     * 
     */
    public static String ReleaseAction_DisplayName() {
        return holder.format("ReleaseAction.DisplayName");
    }

    /**
     * Release New Version
     * 
     */
    public static Localizable _ReleaseAction_DisplayName() {
        return new Localizable(holder, "ReleaseAction.DisplayName");
    }

    /**
     * Monitor Maven Process
     * 
     */
    public static String MavenProbeAction_DisplayName() {
        return holder.format("MavenProbeAction.DisplayName");
    }

    /**
     * Monitor Maven Process
     * 
     */
    public static Localizable _MavenProbeAction_DisplayName() {
        return new Localizable(holder, "MavenProbeAction.DisplayName");
    }

    /**
     * Discovered a new module {0} {1}
     * 
     */
    public static String MavenModuleSetBuild_DiscoveredModule(Object arg1, Object arg2) {
        return holder.format("MavenModuleSetBuild.DiscoveredModule", arg1, arg2);
    }

    /**
     * Discovered a new module {0} {1}
     * 
     */
    public static Localizable _MavenModuleSetBuild_DiscoveredModule(Object arg1, Object arg2) {
        return new Localizable(holder, "MavenModuleSetBuild.DiscoveredModule", arg1, arg2);
    }

    /**
     * No such file {0}
     * Perhaps you need to specify the correct POM file path in the project configuration?
     * 
     */
    public static String MavenModuleSetBuild_NoSuchPOMFile(Object arg1) {
        return holder.format("MavenModuleSetBuild.NoSuchPOMFile", arg1);
    }

    /**
     * No such file {0}
     * Perhaps you need to specify the correct POM file path in the project configuration?
     * 
     */
    public static Localizable _MavenModuleSetBuild_NoSuchPOMFile(Object arg1) {
        return new Localizable(holder, "MavenModuleSetBuild.NoSuchPOMFile", arg1);
    }

    /**
     * No classworlds*.jar found in {0} -- Is this a valid maven2/3 directory?
     * 
     */
    public static String MavenProcessFactory_ClassWorldsNotFound(Object arg1) {
        return holder.format("MavenProcessFactory.ClassWorldsNotFound", arg1);
    }

    /**
     * No classworlds*.jar found in {0} -- Is this a valid maven2/3 directory?
     * 
     */
    public static Localizable _MavenProcessFactory_ClassWorldsNotFound(Object arg1) {
        return new Localizable(holder, "MavenProcessFactory.ClassWorldsNotFound", arg1);
    }

    /**
     * No such settings file {0} exists
     * Please verify that your alternate settings file is specified properly and exists in the workspace.
     * 
     */
    public static String MavenModuleSetBuild_NoSuchAlternateSettings(Object arg1) {
        return holder.format("MavenModuleSetBuild.NoSuchAlternateSettings", arg1);
    }

    /**
     * No such settings file {0} exists
     * Please verify that your alternate settings file is specified properly and exists in the workspace.
     * 
     */
    public static Localizable _MavenModuleSetBuild_NoSuchAlternateSettings(Object arg1) {
        return new Localizable(holder, "MavenModuleSetBuild.NoSuchAlternateSettings", arg1);
    }

    /**
     * Maven failed with error.
     * 
     */
    public static String MavenBuilder_Failed() {
        return holder.format("MavenBuilder.Failed");
    }

    /**
     * Maven failed with error.
     * 
     */
    public static Localizable _MavenBuilder_Failed() {
        return new Localizable(holder, "MavenBuilder.Failed");
    }

    /**
     * Aborted
     * 
     */
    public static String MavenBuilder_Aborted() {
        return holder.format("MavenBuilder.Aborted");
    }

    /**
     * Aborted
     * 
     */
    public static Localizable _MavenBuilder_Aborted() {
        return new Localizable(holder, "MavenBuilder.Aborted");
    }

    /**
     * Alternate settings file must be a relative path.
     * 
     */
    public static String MavenModuleSet_AlternateSettingsRelativePath() {
        return holder.format("MavenModuleSet.AlternateSettingsRelativePath");
    }

    /**
     * Alternate settings file must be a relative path.
     * 
     */
    public static Localizable _MavenModuleSet_AlternateSettingsRelativePath() {
        return new Localizable(holder, "MavenModuleSet.AlternateSettingsRelativePath");
    }

    /**
     * Repository URL is mandatory
     * 
     */
    public static String RedeployPublisher_RepositoryURL_Mandatory() {
        return holder.format("RedeployPublisher.RepositoryURL.Mandatory");
    }

    /**
     * Repository URL is mandatory
     * 
     */
    public static Localizable _RedeployPublisher_RepositoryURL_Mandatory() {
        return new Localizable(holder, "RedeployPublisher.RepositoryURL.Mandatory");
    }

    /**
     * Build failed before it gets to this module
     * 
     */
    public static String MavenBuild_FailedEarlier() {
        return holder.format("MavenBuild.FailedEarlier");
    }

    /**
     * Build failed before it gets to this module
     * 
     */
    public static Localizable _MavenBuild_FailedEarlier() {
        return new Localizable(holder, "MavenBuild.FailedEarlier");
    }

    /**
     * Deploy artifacts to Maven repository
     * 
     */
    public static String RedeployPublisher_getDisplayName() {
        return holder.format("RedeployPublisher.getDisplayName");
    }

    /**
     * Deploy artifacts to Maven repository
     * 
     */
    public static Localizable _RedeployPublisher_getDisplayName() {
        return new Localizable(holder, "RedeployPublisher.getDisplayName");
    }

    /**
     * Module
     * 
     */
    public static String MavenModule_Pronoun() {
        return holder.format("MavenModule.Pronoun");
    }

    /**
     * Module
     * 
     */
    public static Localizable _MavenModule_Pronoun() {
        return new Localizable(holder, "MavenModule.Pronoun");
    }

    /**
     * Triggering a new build of {0}
     * 
     */
    public static String MavenBuild_Triggering(Object arg1) {
        return holder.format("MavenBuild.Triggering", arg1);
    }

    /**
     * Triggering a new build of {0}
     * 
     */
    public static Localizable _MavenBuild_Triggering(Object arg1) {
        return new Localizable(holder, "MavenBuild.Triggering", arg1);
    }

    /**
     * Asynchronous execution failure
     * 
     */
    public static String MavenBuilder_AsyncFailed() {
        return holder.format("MavenBuilder.AsyncFailed");
    }

    /**
     * Asynchronous execution failure
     * 
     */
    public static Localizable _MavenBuilder_AsyncFailed() {
        return new Localizable(holder, "MavenBuilder.AsyncFailed");
    }

    /**
     * Deploy to Maven repository
     * 
     */
    public static String MavenRedeployer_DisplayName() {
        return holder.format("MavenRedeployer.DisplayName");
    }

    /**
     * Deploy to Maven repository
     * 
     */
    public static Localizable _MavenRedeployer_DisplayName() {
        return new Localizable(holder, "MavenRedeployer.DisplayName");
    }

    /**
     * A Maven installation needs to be available for this project to be built.
     * Either your server has no Maven installations defined, or the requested Maven version does not exist.
     * 
     */
    public static String MavenModuleSetBuild_NoMavenInstall() {
        return holder.format("MavenModuleSetBuild.NoMavenInstall");
    }

    /**
     * A Maven installation needs to be available for this project to be built.
     * Either your server has no Maven installations defined, or the requested Maven version does not exist.
     * 
     */
    public static Localizable _MavenModuleSetBuild_NoMavenInstall() {
        return new Localizable(holder, "MavenModuleSetBuild.NoMavenInstall");
    }

    /**
     * Build a maven2/3 project
     * 
     */
    public static String MavenModuleSet_DiplayName() {
        return holder.format("MavenModuleSet.DiplayName");
    }

    /**
     * Build a maven2/3 project
     * 
     */
    public static Localizable _MavenModuleSet_DiplayName() {
        return new Localizable(holder, "MavenModuleSet.DiplayName");
    }

    /**
     * Reusing existing maven process
     * 
     */
    public static String ProcessCache_Reusing() {
        return holder.format("ProcessCache.Reusing");
    }

    /**
     * Reusing existing maven process
     * 
     */
    public static Localizable _ProcessCache_Reusing() {
        return new Localizable(holder, "ProcessCache.Reusing");
    }

    /**
     * Waiting for Jenkins to finish collecting data
     * 
     */
    public static String MavenBuilder_Waiting() {
        return holder.format("MavenBuilder.Waiting");
    }

    /**
     * Waiting for Jenkins to finish collecting data
     * 
     */
    public static Localizable _MavenBuilder_Waiting() {
        return new Localizable(holder, "MavenBuilder.Waiting");
    }

    /**
     * Failed to parse POMs
     * 
     */
    public static String MavenModuleSetBuild_FailedToParsePom() {
        return holder.format("MavenModuleSetBuild.FailedToParsePom");
    }

    /**
     * Failed to parse POMs
     * 
     */
    public static Localizable _MavenModuleSetBuild_FailedToParsePom() {
        return new Localizable(holder, "MavenModuleSetBuild.FailedToParsePom");
    }

}
